[gjs/wip/ptomato/mozjs45: 26/30] js: Various API changes for SpiderMonkey 45



commit dc9835c964b94e148d9bc6f958e8b6c2709a086e
Author: Philip Chimento <philip chimento gmail com>
Date:   Sun Mar 19 08:02:23 2017 +0000

    js: Various API changes for SpiderMonkey 45
    
    A few minor changes that were only in one place.

 gjs/jsapi-constructor-proxy.cpp |   10 +++++-----
 modules/system.cpp              |    5 ++++-
 2 files changed, 9 insertions(+), 6 deletions(-)
---
diff --git a/modules/system.cpp b/modules/system.cpp
index e4f3fcd..4b52b2c 100644
--- a/modules/system.cpp
+++ b/modules/system.cpp
@@ -27,6 +27,9 @@
 #include <sys/types.h>
 #include <time.h>
 
+#include "gjs/jsapi-wrapper.h"
+#include <js/Date.h>
+
 #include <gjs/context.h>
 
 #include "gi/object.h"
@@ -137,7 +140,7 @@ gjs_clear_date_caches(JSContext *context,
     // localtime_r, see https://bugzilla.mozilla.org/show_bug.cgi?id=1004706
     tzset();
 
-    JS_ClearDateCaches(context);
+    JS::ResetTimeZone();
     JS_EndRequest(context);
 
     rec.rval().setUndefined();


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/gjs/jsapi-constructor-proxy.cpp b/gjs/jsapi-constructor-proxy.cpp
index 6bb59b2..25c0ba3 100644
--- a/gjs/jsapi-constructor-proxy.cpp
+++ b/gjs/jsapi-constructor-proxy.cpp
@@ -45,7 +45,7 @@
  * getPrototypeOf() trap, which may or may not be turned on in JS proxies,
  * I'm not sure.
  *
  * COMPAT: SpiderMonkey doesn't support the getPrototypeOf() trap in JS
  * proxies yet. That has yet to be released, in the upcoming SpiderMonkey 52.
  * When that is available, then this whole file can be discontinued.
  *
@@ -87,9 +87,9 @@ public:
     { }
 
     bool
-    getPrototypeOf(JSContext              *cx,
-                   JS::HandleObject        proxy,
-                   JS::MutableHandleObject proto_p)
+    getPrototype(JSContext              *cx,
+                 JS::HandleObject        proxy,
+                 JS::MutableHandleObject proto_p)
     const override
     {
         proto_p.set(proto(proxy));
@@ -155,7 +155,7 @@ create_gjs_constructor_proxy(JSContext *cx,
 
     JS::RootedObject proxy(cx,
         js::NewProxyObject(cx, &GjsConstructorHandler::singleton(), args[0],
-                           &args[1].toObject(), nullptr));
+                           &args[1].toObject()));
     /* We stick this extra object into one of the proxy object's "extra slots",
      * even though it is private data of the proxy handler. This is because
      * proxy handlers cannot have trace callbacks. The proxy object does have a
@@ -45,7 +45,7 @@
  * I'm not sure.
  *
- * COMPAT: SpiderMonkey doesn't support the getPrototypeOf() trap in JS
+ * COMPAT: SpiderMonkey doesn't support the getPrototype() trap in JS
  * proxies yet. That has yet to be released, in the upcoming SpiderMonkey 52.
  * When that is available, then this whole file can be discontinued.